<?php
/**
 * Created by PhpStorm.
 * User: MATHEUSSILVA
 * Date: 26/03/2015
 * Time: 11:17
 */

namespace Folha\Logic\ObrigacaoLegal\RAIS;

use \Folha\Entities\GpeVinculoh;

use \Folha\Entities\GpeVinculom;

use \Folha\Logic\ObrigacaoLegal\RAIS\Entities\Tipo01Base;

use \Geral\Entities\Comunicaparc;

use \Geral\Entities\Enderecoparc;

use \Geral\Entities\Estruturam;

use \Geral\Entities\Estruturah;

use \Geral\Entities\Municipio;

use \Geral\Repositories\Estruturam as EstruturaRepositories;

use \HCM\Util\DateUtil;

class Tipo01 extends Tipo01Base
{

    //ATRIBUTOS UTILIZADO
    /** @var $estruturam Estruturam */
    private $estruturam;
    /** @var $estruturah Estruturah */
    private $estruturah;
    /** @var  $tipo02 Tipo02[] */
    private $tipo02;
    /** @var  $vinculoms GpeVinculo[] */
    private $vinculos;
    /** @var  int $nrformrais */
    private $nrformrais;

    /**
     * Construtor
     * @param Estruturam $estruturam
     * @param Estruturah $estruturah
     * @param $ano
     * @param bool $centralPag
     * @param int $sindicato
     * @throws \Exception
     */
    function __construct( $estruturam, $estruturah, $ano, $centralPag = null, $sindicato = null, $nrformrais)
    {
        $this->ano = $ano;
        $this->estruturam = $estruturam;
        $this->estruturah = $estruturah;
        $this->nrformrais = $nrformrais;
        $default = $this->setDefaultValue();
        $basicInfo = $this->setBasicInfo($estruturam, $estruturah, $ano, $sindicato);
        $adressInfo = $this->setAdress();
        $comunInfo = $this->setComunicat();
        $patInfo = $this->setPatInfo();


    }

    /**
     * Seta os valores que são padrões
     * @return bool
     */
    private function setDefaultValue()
    {
        $this->prefixo = '00';
        $this->constante = '0';
        $this->tipoRegistro = 1;
        $this->zeros = '00';
        $this->espacos = '';
        $this->contrAssocCnpj = 0;
        $this->contrAssocValor = 0;
        $this->contrConfedCnpj = 0;
        $this->contrConfedValor = 0;
        $this->contrSindiCnpj = 0;
        $this->contrSindiValor = 0;
        $this->contrAssistCnpj = 0;
        $this->contrAssistValor = 0;
        $this->centPagSindical = 2;
        $this->centPagSindCnpj = 0;
        $this->empresaFiliSind = 2;
        $this->tipoSisContrPto = '02';
        $this->infoExclEmpresa = '';
        $this->tipoRais = 00;

        return true;
    }

    /**
     * Busca os objetos de Estruturam e Estruturah
     * @param Estruturam $estruturam
     * @param Estruturah $estruturah
     * @param int $sindicato
     * @throws \Exception
     */
    private function setBasicInfo($estruturam, $estruturah, $sindicato)
    {
        try {

            if(!$estruturah){
                $params = array(
                    1 => $estruturam->getNrestruturam()
                );
                throw Exception::newException(Exception::ERRO_ESTRUTURAM_NAO_LOCA, $params, Exception::EXCEPTION_ERRO);
            }

            $this->cnpj = $estruturah->getCdcnpjestrut();
            $this->razaoSocial = $estruturah->getNmrazsocestrut();
            $this->cnae = $estruturah->getCdcnae();
            $this->natJuridica = $estruturah->getCdnatujuri();
            $this->dataBase = $estruturah->getDtbasesindical();
            $this->matricula = $estruturah->getCdceiestrut();

            if($this->estruturah->getDtextincao() instanceof \DateTime ){
                $this->encerramento = '1';
                $this->dataEncerramento = $this->estruturah->getDtextincao()->format('d/m/Y');
                $this->atividadeAno = ($this->estruturah->getDtextincao()->format('Y') >= $this->ano)?'1':'2';
            }elseif(!is_null($this->estruturah->getDtextincao())){
                $this->encerramento = '1';
                $this->dataEncerramento = $this->estruturah->getDtextincao();
                $this->atividadeAno = (substr($this->estruturah->getDtextincao(),6, 4) >= $this->ano)?'1':'2';
            }else{
                $this->encerramento = '2';
                $this->atividadeAno = '2';
            }
            switch($this->estruturah->getIdtipoempr()){
                case('1'):{
                    $this->porte = 1;
                    break;
                }
                case('2'):{
                    $this->porte = 2;
                    break;
                }
                default:{
                    $this->porte = 3;
                    break;
                }
            }
            if($estruturah->getIdoptsimples() == 'S'){
                $this->optSimples = 1;
            }else{
                $this->optSimples = 2;
            }
            switch($estruturah->getIdtipoempr()){
                case (1):{
                    $this->tipoInscricao = '1';
                    break;
                }
                case (2):{
                    $this->tipoInscricao = '2';
                    break;
                }
                default: {
                    $this->tipoInscricao = '3';
                    break;
                }
            }

            return true;

        } catch (\Exception $e) {
            throw $e;
        }
    }

    /**
     * Busca informações sobre o endereço da estrutura
     * @return boolean
     * @throws \Exception
     */
    private function setAdress()
    {
        try {

            // Buscar o endereço da estrutura
            $where = "NRPARCNEGOCIO = :P_NRPARCNEGOCIO AND NRORG = :P_NRORG";
            $params = array(
                'P_NRPARCNEGOCIO' => $this->estruturam->getNrparcnegocio(),
                'P_NRORG' => $this->estruturam->getNrorg()
            );
            $orderBy = "";
            $endereco = Enderecoparc::getObjectByWhere($where, $params, $orderBy);
            /** @var $endereco Enderecoparc */

            if($endereco){
                $this->logradouro = $endereco->getDsendereco();
                $this->numero = $endereco->getNrimovelendereco();
                $this->complemento = $endereco->getDscompleendereco();
                $this->bairro = $endereco->getNmbairroendereco();
                $this->cep = $endereco->getNrcependereco();
                $this->uf = $endereco->getSgestado();
                if($endereco->getCdmunicipio()){
                    $this->codMunicipio = $endereco->getMunicipio()->getCdmunicibge();
                    $this->municipio = $endereco->getMunicipio()->getNmmunicipio();
                }else{
                    $params = array(
                        $this->estruturam->getNrestruturam(),
                        $this->estruturam->getNmestruturam(),
                    );
                    Exception::newException(Exception::ALERTA_MUNICIPIO_ESTRUTURA, $params, Exception::EXCEPTION_ALERTA);
                }
            }else{
                $params = array(
                    $this->estruturam->getNrestruturam(),
                    $this->estruturam->getNmestruturam(),
                );
                Exception::newException(Exception::ALERTA_ENDERECO_ESTRUTURA, $params, Exception::EXCEPTION_ALERTA);
            }

            return true;

        } catch (\Exception $e) {
            throw $e;
        }
    }

    /**
     * BUSCA A FORMA DE COMUNICAÇÃO
     * @return boolean
     * @throws \Exception
     */
    private function setComunicat()
    {
        try {
            // BUSCA O TELEFONE DA EMPRESA
            $where = "NRPARCNEGOCIO = :P_NRPARCNEGOCIO AND NRORG = :P_NRORG AND CDFORMACOMU = :P_CDFORMACOMU";
            $params = array(
                'P_NRPARCNEGOCIO' => $this->estruturam->getNrparcnegocio(),
                'P_NRORG' => $this->estruturam->getNrorg(),
                'P_CDFORMACOMU' => '01'
            );
            $orderBy = "NRCOMUNICAPARC DESC";
            $telefone = Comunicaparc::getObjectByWhere($where, $params, $orderBy);
            /** @var $telefone Comunicaparc */

            //BUSCA O E-MAIL DA EMPRESA
            $where = "NRPARCNEGOCIO = :P_NRPARCNEGOCIO AND NRORG = :P_NRORG AND CDFORMACOMU = :P_CDFORMACOMU";
            $params = array(
                'P_NRPARCNEGOCIO' => $this->estruturam->getNrparcnegocio(),
                'P_NRORG' => $this->estruturam->getNrorg(),
                'P_CDFORMACOMU' => '05'
            );
            $orderBy = "NRCOMUNICAPARC DESC";
            $email = Comunicaparc::getObjectByWhere($where, $params, $orderBy);
            /** @var $email Comunicaparc */

            if($telefone){
                $this->ddd = $telefone->getCdprefixcomuparc();
                $this->numeroTel = $telefone->getCdcomunicaparc();
            }else{
                $params = array(
                    $this->estruturam->getNrestruturam(),
                    $this->estruturam->getNmestruturam(),
                );
                Exception::newException(Exception::ALERTA_TELEFONE_ESTRUTURA, $params, Exception::EXCEPTION_ALERTA);
            }
            if($email){
                $this->email = $email->getCdcomunicaparc();
            }else{
                $params = array(
                    $this->estruturam->getNrestruturam(),
                    $this->estruturam->getNmestruturam(),
                );
                Exception::newException(Exception::ALERTA_EMAIL_ESTRUTURA, $params, Exception::EXCEPTION_ALERTA);
            }

            return true;
        } catch (\Exception $e) {
            throw $e;
        }

    }


    private function setPatInfo()
    {

        if($this->estruturah->getIdparticipat() == 'S'){
            $this->optPat = 1;

            $ma5sm = EstruturaRepositories::getVincSalAcima5SM($this->estruturam->getNrestruturam(), $this->estruturam->getNrorg(), $this->ano);
            $me5sm = EstruturaRepositories::getVincSalabaixo5SM($this->estruturam->getNrestruturam(), $this->estruturam->getNrorg(), $this->ano);

            $this->patMais5 = $ma5sm['QTD'];
            $this->patMenos5 = $me5sm['QTD'];
            $this->servicoProp = EstruturaRepositories::quantFuncPorPat($this->estruturam->getNrestruturam(), $this->estruturam->getNrorg(), 1, $this->ano);
            $this->admCozinha = EstruturaRepositories::quantFuncPorPat($this->estruturam->getNrestruturam(), $this->estruturam->getNrorg(), 2, $this->ano);
            $this->convenio = EstruturaRepositories::quantFuncPorPat($this->estruturam->getNrestruturam(), $this->estruturam->getNrorg(), 3, $this->ano);
            $this->transportadas = EstruturaRepositories::quantFuncPorPat($this->estruturam->getNrestruturam(), $this->estruturam->getNrorg(), 4, $this->ano);
            $this->cesta = EstruturaRepositories::quantFuncPorPat($this->estruturam->getNrestruturam(), $this->estruturam->getNrorg(), 5, $this->ano);
            $this->alimentConvenio = EstruturaRepositories::quantFuncPorPat($this->estruturam->getNrestruturam(), $this->estruturam->getNrorg(), 6, $this->ano);
        }else{
            $this->optPat = 2;

            $this->patMais5 = 0;
            $this->patMenos5 = 0;
            $this->servicoProp = 0;
            $this->admCozinha = 0;
            $this->convenio = 0;
            $this->transportadas = 0;
            $this->cesta = 0;
            $this->alimentConvenio = 0;
        }

        return true;

    }

    /**
     * Busca os Vínculos
     * @param int $nrorg
     * @param array $nrvinculoms
     */
    private function buscaVinculosRais02($nrorg, $nrvinculoms, $dtmescompetenc)
    {
        foreach($nrvinculoms as $nrvinculom){
            $vinculo = new GpeVinculo();
            $vinculo->searchVinculom($nrorg, $nrvinculom, $dtmescompetenc);
            if($vinculo){
                $this->vinculos[] = $vinculo;
            }
        }
    }

    /**
     * Seta Informações sobre a Rais tipo 02
     * @param int $grupoIncidencia
     * @param array $nrvinculos
     * @throws \Exception
     */
    public function setRais02($grupoIncidencia, $nrvinculos)
    {
        $dataInicial = DateUtil::getDataDeString("01/01/{$this->ano}", DateUtil::FORMATO_BRASILEIRO, true);
        $dataFinal = DateUtil::getDataDeString("31/12/{$this->ano}", DateUtil::FORMATO_BRASILEIRO, true);

        $where = "NRESTRUTLEGAL = :P_NRESTRUTLEGAL AND NRORG = :P_NRORG AND DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) DTMESCOMPETENC FROM GPE_VINCULOH MAX_VINCULOH WHERE MAX_VINCULOH.NRVINCULOM = e.NRVINCULOM AND MAX_VINCULOH.NRORG = e.NRORG AND MAX_VINCULOH.DTMESCOMPETENC <= :P_DTMESCOMPETENC)".($nrvinculos?" $nrvinculos":"");
        $params = array(
            'P_NRESTRUTLEGAL' => $this->estruturam->getNrestruturam(),
            'P_NRORG' => $this->estruturam->getNrorg(),
            'P_DTMESCOMPETENC' => "31/12/{$this->ano}"
        );
        $vinculos = GpeVinculoh::getObjectsByWhere($where, $params);/** @var GpeVinculoh[] $vinculos */


        if($vinculos){
            foreach($vinculos as $vinculoh){
                $vinculom = $vinculoh->getVinculom();
                $dtadmissao = $vinculom->getDtadmissaovinc();
                $dtdemissao = $vinculom->getDtrescisaovinc();
                $tpVinculo = $vinculom->getNrtipovinculom();

                if(!($dtadmissao instanceof \DateTime)){
                    $dtadmissao = DateUtil::getDataDeString(substr($dtadmissao, 0, 10),DateUtil::FORMATO_BRASILEIRO, true);
                }
                if(!($dtdemissao instanceof \DateTime) && !is_null($dtdemissao)){
                    $dtdemissao = DateUtil::getDataDeString(substr($dtdemissao, 0, 10),DateUtil::FORMATO_BRASILEIRO, true);
                }

                if(
                    (($dtadmissao<=$dataFinal) && (($dtdemissao>$dataInicial) ||is_null($dtdemissao)))
                    &&(($tpVinculo == 1) ||($tpVinculo == 7) ||($tpVinculo == 9))
                ){
                    $this->tipo02[] = new Tipo02($vinculom, $vinculoh, $this->ano, $this->estruturah->getCdcnpjestrut(), $grupoIncidencia, $this->nrformrais);
                }
            }
        }else{
            $params = array(
                $this->estruturam->getNrestruturam(),
                $this->estruturam->getNmestruturam()
            );
            Exception::newException(Exception::ALERTA_ESTRUT_SEM_VINCUL, $params, Exception::EXCEPTION_ALERTA);
        }
    }

    /**
     * Retorna um array contendo todos os magneticos de tipo 02
     * @return array
     * @throws \Exception
     */
    public function getTipo02()
    {
        $linhas = array();
        foreach($this->tipo02 as $tipo02){
            $linhas[] = $tipo02->getRow();
        }
        return $linhas;
    }

    public function getInfoZero()
    {
        return array(
            'CNPJ' => $this->cnpj,
            'PREFIXO' => $this->prefixo,
        );
    }

    public function getQuantDois()
    {
        return count($this->tipo02);
    }

} 




















































