<?php
/**
 * Namespace Planejamento\Entities;
 *
 * PHP version 5
 *
 * @category Php
 * @package  Planejamento\Entities
 * @author   andreteixeira <andre.teixeira@teknisa.com>
 * @license  www.teknisa.com Teknisa
 * @link     http://localhost:9090/tecfood
 */
namespace Planejamento\Entities;

use \Geral\Util\DateUtil;
use \Geral\Util\Ambiente;
use \Setforms2\Shared\Registry;
use \Geral\Entities\Filial;
use Symfony\Component\Validator\Constraints\DateTime;
use \Planejamento\Entities\Logcalencard;

/**
 * Class Calencard
 *
 * @category Php
 * @package  Planejamento\Entities
 * @author   andreteixeira <andre.teixeira@teknisa.com>
 * @license  www.teknisa.com Teknisa
 * @link     http://localhost:9090/tecfood
 */
class Calencard extends Base\Calencard
{
    /**
     * Função que insere um registro no bando de dados, na tabela CALENCARD
     * de acordo com os parâmetros passados.
     *
     * @param $cdfilial
     * @param $dtmescalencard
     * @param $nrorg
     * @param $dtprevlibecard
     * @param $dtlimaprovfili
     * @param $dtlimaprovmatr
     * @param $dtbasconcusplan
     * @param $qtdiaproraprov
     *
     * @return null
     * @throws \Exception
     */
    public static function insere(
        $cdfilial, $dtmescalencard, $nrorg, $dtprevlibecard, $dtlimaprovfili,
        $dtlimaprovmatr, $dtbasconcusplan, $qtdiaproraprov
    ) {
        $connection = Registry::getEntityManager();
        $connection->beginTransaction();
        try {
            $calencard = new Calencard;
            $logcalencard = new Logcalencard;
            $calencard->setCdfilial($cdfilial);
            $calencard->setDtmescalencard($dtmescalencard);
            $calencard->setNrorg($nrorg);
            $calencard->setDtprevlibecard($dtprevlibecard);
            $calencard->setDtlimaprovfili($dtlimaprovfili);
            $calencard->setDtlimaprovmatr($dtlimaprovmatr);
            if (empty($dtbasconcusplan) === false) {
                $calencard->setDtbasconcusplan($dtbasconcusplan);
            }
            $calencard->setQtdiaproraprov($qtdiaproraprov);
            $calencard->setDtinclusao(DateUtil::getDataAtual());
            //$logcalencard->setFilial(Filial::retornaFilial($cdfilial, $nrorg));
            $calencard->setCdoperinclusao(Ambiente::getCdOperador());
            $calencard->setNrorginclusao(Ambiente::getNrorg());
            $calencard->setDtultatu(DateUtil::getDataAtual());
            $calencard->setNrorgultatu(Ambiente::getNrorg());
            $calencard->setCdoperultatu(Ambiente::getCdOperador());
            //
            $logcalencard->setCdfilial($cdfilial);
            $logcalencard->setDtmescalencard($dtmescalencard);
            $logcalencard->setNrorg($nrorg);
            $logcalencard->setDtprevlibecarddep($dtprevlibecard);
            $logcalencard->setDtlimaprovfilidep($dtlimaprovfili);
            $logcalencard->setDtlimaprovmatrdep($dtlimaprovmatr);
            $logcalencard->setQtdiaproraprovdep($qtdiaproraprov);
            $logcalencard->setDtinclusao(DateUtil::getDataAtual());
            $logcalencard->setCdoperinclusao(Ambiente::getCdOperador());
            $logcalencard->setNrorginclusao(Ambiente::getNrorg());
            $logcalencard->setDtultatu(DateUtil::getDataAtual());
            $logcalencard->setNrorgultatu(Ambiente::getNrorg());
            $logcalencard->setCdoperultatu(Ambiente::getCdOperador());
            $logcalencard->setCdoperador(Ambiente::getCdOperador());
            $logcalencard->setDtaltcalencard(DateUtil::getDataAtual());
            //
            $calencard->persist();
            $logcalencard->persist();
            $connection->flush();
            $connection->commit();
        } catch (\Exception $e) {
            $connection->rollback();
            throw $e;
        }
    }

    /**
     * Função que atualiza um registro do banco de dados, na tabela CALENCARD
     * de acordo com os parâmetros passados.
     *
     * @param $calencard
     * @param $dtprevlibecard
     * @param $dtlimaprovfili
     * @param $dtlimaprovmatr
     * @param $dtbasconcusplan
     * @param $qtdiaproraprov
     *
     * @return null
     * @throws \Exception
     */
    public static function update(
        $calencard, $dtprevlibecard, $dtlimaprovfili, $dtlimaprovmatr,
        $dtbasconcusplan, $qtdiaproraprov
    ) {
        $connection = Registry::getEntityManager();
        $connection->beginTransaction();
        try {
            if ($calencard instanceof self) {
                $cdfilial       = $calencard->getCdfilial();
                $dtmescalencard = $calencard->getDtmescalencard();
                $nrorg          = $calencard->getNrorg();
                $logcalencard = Logcalencard::getObjectByWhere(
                    'CDFILIAL = ? AND NRORG = ? AND DTMESCALENCARD = ?',
                    array($cdfilial, $nrorg, $dtmescalencard)
                );
                if ($logcalencard instanceof Logcalencard) {
                    $dt = $logcalencard->getDtprevlibecarddep();
                    if ($dt instanceof DateUtil === false) {
                        $dt = DateUtil::getDataDeString($dt, "d/m/Y H:i:s");
                    }
                    $dt->setTime(00, 00, 00);
                    $logcalencard->setDtprevlibecardant(
                        $dt
                    );
                    //
                    $dt = $logcalencard->getDtlimaprovfilidep();
                    if ($dt instanceof DateUtil === false) {
                        $dt = DateUtil::getDataDeString($dt, "d/m/Y H:i:s");
                    }
                    $dt->setTime(00, 00, 00);
                    $logcalencard->setDtlimaprovfiliant(
                        $dt
                    );
                    //
                    $dt = $logcalencard->getDtlimaprovmatrdep();
                    if ($dt instanceof DateUtil === false) {
                        $dt = DateUtil::getDataDeString($dt, "d/m/Y H:i:s");
                    }
                    $dt->setTime(00, 00, 00);
                    $logcalencard->setDtlimaprovmatrant(
                        $dt
                    );
                    $logcalencard->setQtdiaproraprovant(
                        $logcalencard->getQtdiaproraprovdep()
                    );
                    //
                    $logcalencard->setDtprevlibecarddep($dtprevlibecard);
                    $logcalencard->setDtlimaprovfilidep($dtlimaprovfili);
                    $logcalencard->setDtlimaprovmatrdep($dtlimaprovmatr);
                    $logcalencard->setQtdiaproraprovdep($qtdiaproraprov);
                    $logcalencard->setDtultatu(DateUtil::getDataAtual());
                    $logcalencard->setNrorgultatu(Ambiente::getNrorg());
                    $logcalencard->setCdoperultatu(Ambiente::getCdOperador());
                    //
                    $calencard->setDtprevlibecard($dtprevlibecard);
                    $calencard->setDtlimaprovfili($dtlimaprovfili);
                    $calencard->setDtlimaprovmatr($dtlimaprovmatr);
                    $calencard->setDtbasconcusplan($dtbasconcusplan);
                    $calencard->setQtdiaproraprov($qtdiaproraprov);
                    //$calencard->setIdativo($idativo);
                    $calencard->setDtultatu(DateUtil::getDataAtual());
                    $calencard->setNrorgultatu(Ambiente::getNrorg());
                    $calencard->setCdoperultatu(Ambiente::getCdOperador());
                    //
                    $logcalencard->persist();
                    $calencard->persist();
                    $connection->flush();
                    $connection->commit();
                }
            }
        } catch (\Exception $e) {
            $connection->rollback();
            throw $e;
        }
    }

    /**
     * Função que faz uma busca no banco de dados, na tabela CALENCARD,
     * de acordo com os parâmetros passados.
     *
     * @param $cdfilial
     * @param $dtmescalencard
     * @param $nrorg
     *
     * @return bool.
     */
    public static function busca($cdfilial, $dtmescalencard, $nrorg)
    {
        $calencard = Calencard::getObjectByWhere(
            "CDFILIAL = ? AND TO_CHAR(dtmescalencard, 'DD/MM/YYYY') = ? AND NRORG = ?",
            array($cdfilial, $dtmescalencard, $nrorg)
        );
        return $calencard;
    }
}